@@ -411,8 +411,7 @@ def main():
 #implementation detail of an old version of the IEDriver.'),
 #      ErrorCode(5, 'NoStringWrapper', 'This is probably an unused \
 #implementation detail of an old version of the IEDriver.'),
-#      ErrorCode(6, 'NoSuchDriver', 'This is probably an unused \
-#implementation detail of an old version of the IEDriver.'),
+      ErrorCode(6, 'NoSuchDriver', 'A session is either terminated or not started'),
       ErrorCode(7, 'NoSuchElement', 'An element could not be located on the \
 page using the given search parameters.'),
       ErrorCode(8, 'NoSuchFrame', 'A request to switch to a frame could not be \
@@ -1309,7 +1308,7 @@ location for correctly generating native events.''').
   resources.append(
       SessionResource('/session/:sessionId/buttondown').
       Post('Click and hold the left mouse button (at the coordinates set by the last moveto '
-           'command). Note that the next mouse-related command that should follow is buttondown'
+           'command). Note that the next mouse-related command that should follow is buttonup'
            ' . Any other mouse command (such as click or another call to buttondown) will yield'
            ' undefined behaviour.').
       AddJsonParameter('button', '{number}', 'Which button, enum: `{LEFT = 0, MIDDLE = 1 '
